@@ -30,6 +30,7 @@ from etos_test_runner.etr import ETR
 SUITE = {
     "name": "Test ETOS API scenario",
     "priority": 1,
+    "test_suite_started_id": "577381ad-8356-4939-ab77-02e7abe06699",
     "recipes": [
         {
             "constraints": [
@@ -103,7 +104,6 @@ class TestLogUpload(TestCase):
         os.chdir(self.root)
         self._patch_wait_for_request()
         self._patch_http_request()
-        self._patch_test_suite_started_request()
 
     def _patch_wait_for_request(self):
         """Patch the ETOS library wait for request method."""
@@ -120,18 +120,6 @@ class TestLogUpload(TestCase):
         self.http_request = patcher.start()
         self.http_request.return_value = True
 
-    def _patch_test_suite_started_request(self):
-        """Patch the GraphQL request for test suite started."""
-        patcher = patch("etos_test_runner.lib.testrunner.request_test_suite_started")
-        self.patchers.append(patcher)
-        self.request_test_suite_started = patcher.start()
-        self.request_test_suite_started.return_value = [
-            {
-                "data": {"testSuiteCategories": []},
-                "meta": {"id": self.main_suite_id},
-            }
-        ]
-
     def tearDown(self):
         """Clear the test folder and patchers."""
         os.chdir(self.original)
